Enable checkstyle rule to verify method names

Enabled checkstyle rule "MethodName" which checks
if method names adhere to a naming convention and
fixed the violations it found.

Change-Id: I87448a1fa857e78f33c42090d485bf21a8986ba7
diff --git a/src/main/java/net/onrc/onos/core/datastore/utils/KVObject.java b/src/main/java/net/onrc/onos/core/datastore/utils/KVObject.java
index 568cfc7..618c31e 100644
--- a/src/main/java/net/onrc/onos/core/datastore/utils/KVObject.java
+++ b/src/main/java/net/onrc/onos/core/datastore/utils/KVObject.java
@@ -49,7 +49,7 @@
 
     /**
      * serialized value version stored on data store or
      * {@link IKVTable.VERSION_NONEXISTENT()} if is a new object.
      */
     private long version;
 
@@ -59,7 +59,7 @@
     private Map<Object, Object> propertyMap;
 
     public KVObject(final IKVTable table, final byte[] key) {
-        this(table, key, null, table.VERSION_NONEXISTENT());
+        this(table, key, null, table.getVersionNonexistant());
     }
 
     public KVObject(final IKVTable table, final byte[] key, final byte[] value, final long version) {
@@ -324,7 +324,7 @@
                 }
             } else {
                 log.error("MultiRead error, skipping {}, {}", obj.getTable(), obj);
-                obj.version = obj.getTable().VERSION_NONEXISTENT();
+                obj.version = obj.getTable().getVersionNonexistant();
                 failExists = true;
             }
         }
@@ -49,7 +49,7 @@
     /**
      * serialized value version stored on data store or
-     * {@link IKVTable.VERSION_NONEXISTENT()} if is a new object.
+     * {@link IKVTable.getVersionNonexistant()} if is a new object.
      */
     private long version;